@@ -3,6 +3,7 @@ import asynctest
 import os
 import vcr
 import llm
+import llm.api.openaiapi
 import logging
 
 # Only get API keys if they exist
@@ -46,6 +47,21 @@ class TestOpenAICompletions(unittest.TestCase):
         self.assertTrue(len(response.split(' ')) > 3)
         self.assertTrue(
             '.' in response or '!' in response or '?' in response, response)
+        
+
+    @vcr.use_cassette("tests/fixtures/openai/test_token_overflow.yaml", filter_headers=['authorization'])
+    def test_token_overflow(self):
+        """Test that we can handle a token overflow."""
+        prompt = "Answer basic math question. 2+2=X Then multiply X by 100. Final answer is?"
+        normal_completion = llm.complete(prompt=prompt, engine="openai:gpt-3.5-turbo")
+        chat_completion = llm.chat(prompt, engine="openai:gpt-3.5-turbo")
+        self.assertTrue("400" in normal_completion, normal_completion)
+        self.assertTrue("400" in chat_completion, chat_completion)
+        llm.api.openaiapi.MODEL_CONTEXT_SIZE_LIMITS["gpt-3.5-turbo"] = 10
+        normal_completion = llm.complete(prompt=prompt, engine="openai:gpt-3.5-turbo", prompt_overflow="trim")
+        chat_completion = llm.chat(prompt, engine="openai:gpt-3.5-turbo", prompt_overflow="trim")
+        self.assertTrue("4" in normal_completion and "400" not in normal_completion, normal_completion)
+        self.assertTrue("4" in chat_completion and "400" not in chat_completion, chat_completion)
 
 
 class TestOpenAIStreaming(asynctest.TestCase):
